@@ -122,24 +122,23 @@ user = {
 
 
 test_run_v1 = {
-  "uuid": "31515312-1325132-1235-321335",
   "name": "Test NG run",
   "startedAt": "2019-12-03T10:15:30+01:00",
-  "framework": "testng",
-  "config": {
-    "url": "value",
-    "env": "value",
-    "platform": "value",
-    "platformVersion": "value",
-    "browser": "value",
-    "browserVesrion": "value",
-    "appVersion": "value",
-    "locale": "value",
-    "language": "value",
-    "device": "value"
-  },
-  "launchContext": {
-    "jobNumber": "adsddad",
-    "upstreamJobNumber": "asxsasadas"
-  }
+  "framework": "testng"
+}
+
+
+test_v1 = {
+  "uuid": "1512351235-3215-3125-3215531",
+  "name": "Test ABC",
+  "className": "com.test.MyTests",
+  "methodName": "featureTest()",
+  "startedAt": "2007-12-03T10:15:30Z"
+
+}
+
+
+test_result_v1 = {
+  "result": "failed",
+  "endedAt": "2007-12-03T10:15:30Z"
 }
